@@ -17,12 +17,8 @@
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
  * @file globus_error_openssl.c
+ * @brief Globus Generic Error
  * @author Sam Lang
- * 
- * $RCSfile: globus_error_openssl.c,v $
- * $Revision: 1.21 $
- * $Date: 2007/08/21 16:31:51 $
- *
  */
 #endif
 
@@ -134,17 +130,13 @@ globus_l_gsi_openssl_error_deactivate(void)
 
 #endif
 
-/**
- * @name Get Error Code
- */
-/* @{ */
 /**
  * @ingroup globus_openssl_error_object
- * Get the openssl error code which represents the openssl error
- * from the openssl error handle
+ * Get the OpenSSL error code which represents the OpenSSL error
+ * from the OpenSSL error handle
  *
  * @param handle
- *        The openssl error handle
+ *        The OpenSSL error handle
  * @return
  *        The error code
  */
@@ -152,7 +144,7 @@ unsigned long
 globus_openssl_error_handle_get_error_code(
     globus_openssl_error_handle_t       handle)
 {
-    unsigned long                        error_code;
+    unsigned long                        error_code = 0;
     static char *                       _function_name_ =
         "globus_openssl_error_handle_get_error_code";
 
@@ -164,26 +156,19 @@ globus_openssl_error_handle_get_error_code(
         goto done;
     }
     
-    error_code = 0;
-
  done:
 
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return error_code;
 }
-/* @} */
 
-/**
- * @name Get Error Data
- */
-/* @{ */
 /**
  * @ingroup globus_openssl_error_object
- * Get the openssl error data which contains additional data about the error
- * from the openssl error handle 
+ * Get the OpenSSL error data which contains additional data about the error
+ * from the OpenSSL error handle 
  *
  * @param handle
- *        The openssl error handle
+ *        The OpenSSL error handle
  * @return
  *        The error data
  */
@@ -210,17 +195,12 @@ globus_openssl_error_handle_get_data(
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return data;
 }
-/* @} */
-/**
- * @name Get Error Data Flags
- */
-/* @{ */
 /**
  * @ingroup globus_openssl_error_object
- * Get the openssl error data flags from the openssl error handle
+ * Get the OpenSSL error data flags from the OpenSSL error handle
  *
  * @param handle
- *        The openssl error handle
+ *        The OpenSSL error handle
  * @return
  *        The error data flags
  */
@@ -247,19 +227,14 @@ globus_openssl_error_handle_get_data_flags(
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return flags;
 }
-/* @} */
 
-/**
- * @name Get Filename
- */
-/* @{ */
 /**
  * @ingroup globus_openssl_error_object
- * Get the filename where the openssl error occurred
- *  from the openssl error handle
+ * Get the filename where the OpenSSL error occurred
+ * from the OpenSSL error handle
  *
  * @param handle
- *        The openssl error handle
+ *        The OpenSSL error handle
  * @return
  *        The filename
  */
@@ -286,21 +261,16 @@ globus_openssl_error_handle_get_filename(
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return filename;
 }
-/* @} */
 
-/**
- * @name Get Linenumber
- */
-/* @{ */
 /**
  * @ingroup globus_openssl_error_object
- * Get the linenumber on which the openssl error occurred
- * from the openssl error handle
+ * Get the line number on which the OpenSSL error occurred
+ * from the OpenSSL error handle
  *
  * @param handle
- *        The openssl error handle
+ *        The OpenSSL error handle
  * @return
- *        The linenumber
+ *        The line number
  */
 int
 globus_openssl_error_handle_get_linenumber(
@@ -325,19 +295,14 @@ globus_openssl_error_handle_get_linenumber(
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return linenumber;
 }
-/* @} */
 
-/**
- * @name Get Library
- */
-/* @{ */
 /**
  * @ingroup globus_openssl_error_object
- * Get the library name where the openssl error occurred in
- * from the openssl error handle
+ * Get the library name where the OpenSSL error occurred in
+ * from the OpenSSL error handle
  *
  * @param handle
- *        The openssl error handle
+ *        The OpenSSL error handle
  * @return
  *        The library name
  */
@@ -364,20 +329,15 @@ globus_openssl_error_handle_get_library(
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return library;
 }
-/* @} */
 
 
-/**
- * @name Get Function
- */
-/* @{ */
 /**
  * @ingroup globus_openssl_error_object
- * Get the function name where the openssl error occurred 
- * from the openssl error handle
+ * Get the function name where the OpenSSL error occurred 
+ * from the OpenSSL error handle
  *
  * @param handle
- *        The openssl error handle
+ *        The OpenSSL error handle
  * @return
  *        The function name
  */
@@ -404,21 +364,16 @@ done:
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return function;
 }
-/* @} */
 
-/**
- * @name Get Reason
- */
-/* @{ */
 /**
  * @ingroup globus_openssl_error_object
- * Get the reason string which caused the openssl error 
- * from the openssl error handle
+ * Get the reason string which caused the OpenSSL error 
+ * from the OpenSSL error handle
  *
  * @param handle
- *        The openssl error handle
+ *        The OpenSSL error handle
  * @return
- *        The reson string
+ *        The reason string
  */
 const char *
 globus_openssl_error_handle_get_reason(
@@ -443,25 +398,20 @@ done:
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return reason;
 }
-/* @} */
 
-/**
- * @name Construct Error
- */
-/*@{*/
 /**
  * @ingroup globus_openssl_error_object
  * Allocate and initialize an error of type GLOBUS_ERROR_TYPE_OPENSSL
  * This function, combined with globus_error_initialize_openssl_error()
  * will recursively generate globus error objects (of type globus_object_t)
- * from the errors on openssl's static error stack.  The errors will
+ * from the errors on OpenSSL's static error stack.  The errors will
  * be chained in a causal fashion to provide a path to the root cause
  * of the actual error.  
  *
- * NOTE:  the static stack openssl implements for its errors currently
+ * NOTE:  the static stack OpenSSL implements for its errors currently
  * only supports at most 16 errors, so if more are added, the errors
  * that were added first will be wiped out.  If 16 errors are counted
- * in the chain of openssl errors, its possible that some errors
+ * in the chain of OpenSSL errors, its possible that some errors
  * (including the original error) are missing.
  *
  * @param base_source
@@ -469,9 +419,9 @@ done:
  * @param base_cause
  *        The error object causing the error.  This parameter should
  *        be NULL in nearly all cases, as the root cause of an error
- *        will most likely be in the openssl code itself.  The 
+ *        will most likely be in the OpenSSL code itself.  The 
  *        actual cause of the error is determined from the static 
- *        stack of openssl errors.
+ *        stack of OpenSSL errors.
  *
  * @return
  *        The resulting error object. It is the user's responsibility
@@ -528,12 +478,7 @@ globus_error_construct_openssl_error(
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return error;
 }/* globus_error_construct_openssl_error() */
-/*@}*/
 
-/**
- * @name Initialize Error
- */
-/*@{*/
 /**
  * Initialize a previously allocated error of type
  * GLOBUS_ERROR_TYPE_OPENSSL
@@ -545,11 +490,11 @@ globus_error_construct_openssl_error(
  *        Pointer to the originating module.
  * @param base_cause
  *        The error object causing the error. If this is the original
- *        error this paramater may be NULL.
+ *        error this parameter may be NULL.
  * @param openssl_error_handle
- *        The openssl error handle associated with this error, this
+ *        The OpenSSL error handle associated with this error, this
  *        parameter should already be initialized to contain the
- *        openssl error code associated with the error.
+ *        OpenSSL error code associated with the error.
  * @return
  *        The resulting error object. You may have to call
  *        globus_error_put() on this object before passing it on.
@@ -573,13 +518,7 @@ globus_error_initialize_openssl_error(
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return error;
 }/* globus_error_initialize_openssl_error() */
-/*@}*/
 
-/**
- * @name Get OpenSSL Filename
- * @ingroup globus_openssl_error_object
- */
-/* @{ */
 /**
  * Get the OpenSSL filename where the error occurred 
  *
@@ -587,7 +526,7 @@ globus_error_initialize_openssl_error(
  *        The globus object that represents the error
  *
  * @return
- *        The filename where the openssl error occurred
+ *        The filename where the OpenSSL error occurred
  */
 const char *
 globus_error_openssl_error_get_filename(
@@ -625,22 +564,16 @@ done:
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return filename;
 }
-/* @} */
 
 
 /**
- * @name Get OpenSSL Linenumber
- * @ingroup globus_openssl_error_object
- */
-/* @{ */
-/**
- * Get the OpenSSL linenumber where the error occurred 
+ * Get the OpenSSL line number where the error occurred 
  *
  * @param error
  *        The globus object that represents the error
  *
  * @return
- *        The linenumber where the openssl error occurred
+ *        The line number where the OpenSSL error occurred
  */
 int
 globus_error_openssl_error_get_linenumber(
@@ -678,21 +611,15 @@ done:
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return linenumber;
 }
-/* @} */
 
 /**
- * @name Get OpenSSL Library
- * @ingroup globus_openssl_error_object
- */
-/* @{ */
-/**
- * Get the OpenSSL libraray the error occurred in
+ * Get the OpenSSL library the error occurred in
  *
  * @param error
  *        The globus object that represents the error
  *
  * @return 
- *        The library name where the openssl error occurred
+ *        The library name where the OpenSSL error occurred
  */
 const char *
 globus_error_openssl_error_get_library(
@@ -730,13 +657,7 @@ done:
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return library;
 }
-/* @} */
 
-/**
- * @name Get OpenSSL Function
- * @ingroup globus_openssl_error_object
- */
-/* @{ */
 /**
  * Get the OpenSSL filename where the error occurred 
  *
@@ -744,7 +665,7 @@ done:
  *        The globus object that represents the error
  *
  * @return 
- *        The function name where the openssl error occurred
+ *        The function name where the OpenSSL error occurred
  */
 const char *
 globus_error_openssl_error_get_function(
@@ -782,13 +703,7 @@ globus_error_openssl_error_get_function(
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return function;
 }
-/* @} */
 
-/**
- * @name Get OpenSSL Reason
- * @ingroup globus_openssl_error_object
- */
-/* @{ */
 /**
  * Get the OpenSSL reason for the error
  *
@@ -796,7 +711,7 @@ globus_error_openssl_error_get_function(
  *        The globus object that represents the error
  *
  * @return
- *        The reason for the openssl error
+ *        The reason for the OpenSSL error
  */
 const char *
 globus_error_openssl_error_get_reason(
@@ -834,13 +749,7 @@ done:
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return reason;
 }
-/* @} */
 
-/**
- * @name Get OpenSSL Error Data
- * @ingroup globus_openssl_error_object
- */
-/* @{ */
 /**
  * Get the OpenSSL Error Data
  *
@@ -848,7 +757,7 @@ done:
  *        The globus object that represents the error
  *
  * @return
- *        The error data for the openssl error
+ *        The error data for the OpenSSL error
  */
 const char *
 globus_error_openssl_error_get_data(
@@ -886,13 +795,7 @@ done:
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return data;
 }
-/* @} */
 
-/**
- * @name Get OpenSSL Error Data Flags
- * @ingroup globus_openssl_error_object
- */
-/* @{ */
 /**
  * Get the OpenSSL Error Data Flags
  *
@@ -900,7 +803,7 @@ done:
  *        The globus object that represents the error
  *
  * @return
- *        The error data flags for the openssl error
+ *        The error data flags for the OpenSSL error
  */
 int
 globus_error_openssl_error_get_data_flags(
@@ -938,13 +841,8 @@ done:
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return flags;
 }
-/* @} */
 
 
-/**
- * @name OpenSSL Error Match
- */
-/*@{*/
 /**
  * Check whether the error originated from a specific library, from a specific
  * function and is of a specific type.
@@ -962,9 +860,8 @@ done:
  *        The function to check for
  * @param reason
  *        The type to check for
- * @return
- *        GLOBUS_TRUE - the error matched 
- *        GLOBUS_FALSE - the error failed to match 
+ * @retval GLOBUS_TRUE Error matched 
+ * @retval GLOBUS_FALSE Error failed to match 
  */
 globus_bool_t
 globus_error_match_openssl_error(
@@ -1010,26 +907,21 @@ globus_error_match_openssl_error(
     }
 }
 /* globus_error_match_openssl_error */
-/*@}*/
 
-/**
- * @name Wrap OpenSSL Error
- */
-/* @{ */
 /**
  * Wrap the OpenSSL error and create a wrapped globus error object from the
  * error. 
  * @ingroup globus_openssl_error_utility
  *
- * This function gets all the openssl errors
+ * This function gets all the OpenSSL errors
  * from the error list, and chains them using the globus
  * error string object.  The resulting globus error object
- * is a wrapper to the openssl error at the end of the chain.
+ * is a wrapper to the OpenSSL error at the end of the chain.
  *
  * @param base_source
  *        The module that the error was generated from
  * @param error_type
- *        The type of error encapsulating the openssl error
+ *        The type of error encapsulating the OpenSSL error
  * @param source_file
  *        Name of file.  Use __FILE__
  * @param source_func
@@ -1039,7 +931,7 @@ globus_error_match_openssl_error(
  *        Line number.  Use __LINE__
  * @param format
  *        format string for the description of the error entry
- *        point where the openssl error occurred, should be followed
+ *        point where the OpenSSL error occurred, should be followed
  *        by parameters to fill the format string (like in printf).
  * @return 
  *        The globus error object.  A globus_result_t
@@ -1090,4 +982,3 @@ globus_error_wrap_openssl_error(
     GLOBUS_I_GSI_OPENSSL_ERROR_DEBUG_EXIT;
     return error;
 }
-/* @} */
